@@ -18,10 +18,11 @@ package virtualnetworks
 
 import (
 	"context"
+	"errors"
+	"fmt"
 
 	"github.com/Azure/azure-sdk-for-go/services/network/mgmt/2018-12-01/network"
 	"github.com/Azure/go-autorest/autorest/to"
-	"github.com/pkg/errors"
 	"k8s.io/klog"
 	"sigs.k8s.io/cluster-api-provider-azure/pkg/cloud/azure"
 )
@@ -38,9 +39,9 @@ func (s *Service) Get(ctx context.Context, spec azure.Spec) (interface{}, error)
 	if !ok {
 		return network.VirtualNetwork{}, errors.New("Invalid VNET Specification")
 	}
-	vnet, err := s.Client.Get(ctx, s.Scope.ClusterConfig.NetworkResourceGroup, vnetSpec.Name, "")
+	vnet, err := s.Client.Get(ctx, s.Scope.MachineConfig.NetworkResourceGroup, vnetSpec.Name, "")
 	if err != nil && azure.ResourceNotFound(err) {
-		return nil, errors.Wrapf(err, "vnet %s not found", vnetSpec.Name)
+		return nil, fmt.Errorf("vnet %s not found: %w", vnetSpec.Name, err)
 	} else if err != nil {
 		return vnet, err
 	}
@@ -68,9 +69,9 @@ func (s *Service) CreateOrUpdate(ctx context.Context, spec azure.Spec) error {
 	}
 
 	klog.V(2).Infof("creating vnet %s ", vnetSpec.Name)
-	f, err := s.Client.CreateOrUpdate(ctx, s.Scope.ClusterConfig.NetworkResourceGroup, vnetSpec.Name,
+	f, err := s.Client.CreateOrUpdate(ctx, s.Scope.MachineConfig.NetworkResourceGroup, vnetSpec.Name,
 		network.VirtualNetwork{
-			Location: to.StringPtr(s.Scope.ClusterConfig.Location),
+			Location: to.StringPtr(s.Scope.MachineConfig.Location),
 			VirtualNetworkPropertiesFormat: &network.VirtualNetworkPropertiesFormat{
 				AddressSpace: &network.AddressSpace{
 					AddressPrefixes: &[]string{vnetSpec.CIDR},
@@ -101,18 +102,18 @@ func (s *Service) Delete(ctx context.Context, spec azure.Spec) error {
 		return errors.New("Invalid VNET Specification")
 	}
 	klog.V(2).Infof("deleting vnet %s ", vnetSpec.Name)
-	future, err := s.Client.Delete(ctx, s.Scope.ClusterConfig.NetworkResourceGroup, vnetSpec.Name)
+	future, err := s.Client.Delete(ctx, s.Scope.MachineConfig.NetworkResourceGroup, vnetSpec.Name)
 	if err != nil && azure.ResourceNotFound(err) {
 		// already deleted
 		return nil
 	}
 	if err != nil {
-		return errors.Wrapf(err, "failed to delete vnet %s in resource group %s", vnetSpec.Name, s.Scope.ClusterConfig.NetworkResourceGroup)
+		return fmt.Errorf("failed to delete vnet %s in resource group %s: %w", vnetSpec.Name, s.Scope.MachineConfig.NetworkResourceGroup, err)
 	}
 
 	err = future.WaitForCompletionRef(ctx, s.Client.Client)
 	if err != nil {
-		return errors.Wrap(err, "cannot delete, future response")
+		return fmt.Errorf("cannot delete, future response: %w", err)
 	}
 
 	_, err = future.Result(s.Client)
